@@ -771,7 +771,7 @@ quick_lounge_set_textdomain ()
 	static gboolean domain_setted = FALSE;
 
 	if (!domain_setted) {
-		textdomain (GETTEXT_PACKAGE);
+		/* textdomain (GETTEXT_PACKAGE); FIXME */
 		domain_setted = TRUE;
 	}
 }
